import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.28bc9fc9.js";import{B as m}from"./BaseLayout.72a6c8f2.js";import{d as l,ae as y,c1 as v,_ as u,aZ as g,a_ as b,o as _,a5 as h,e as r,a6 as n,eb as w,e5 as S,J as L,a as k,b as s,f as i,u as x}from"./jwt-decode.esm.54a1ea22.js";import{u as B}from"./editor.02184ced.js";import{A as I}from"./index.482df04a.js";import"./Logo.65e0b37c.js";import"./router.06ee2b9d.js";import"./workspaceStore.fac1e9a9.js";import"./userStore.6ab1e5ac.js";import"./url.f5664225.js";import"./colorHelpers.50ced1e9.js";import"./useCodebaseEvents.276cc8f0.js";import"./contracts.generated.aefe8d0a.js";import"./constants.d569f33d.js";import"./linters.a0f2aa84.js";import"./asyncComputed.47aec2b5.js";import"./index.c7a996a6.js";import"./Breadcrumb.5c786c09.js";import"./index.c8a56795.js";import"./index.966ac1b9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="a9598286-6c52-4d48-911d-a14a6bb8c0f1",e._sentryDebugIdIdentifier="sentry-dbid-a9598286-6c52-4d48-911d-a14a6bb8c0f1")}catch{}})();const $=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=y({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...v(o)}}});const P={class:"v-spinner"};function D(e,o,a,d,c,p){return g((_(),h("div",P,[r("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-even",style:n(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4)],512)),[[b,e.loading]])}const R=u($,[["render",D],["__scopeId","data-v-06538001"]]),j={class:"content"},z=l({__name:"ProjectLogin",setup(e){const o=w(),a=S(),d=B();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function p(){const t=o.query["api-key"];if(typeof t=="string")return t}return L(async()=>{const t=p();if(!t){a.push({name:"error"});return}await d.createLogin(t).then(c),a.push({name:"editor"})}),(t,A)=>(_(),k(m,null,{navbar:s(()=>[i(x(I),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:s(()=>[i(f)]),_:1})]),content:s(()=>[r("div",j,[i(R)])]),_:1}))}});const te=u(z,[["__scopeId","data-v-d2a19803"]]);export{te as default};
//# sourceMappingURL=ProjectLogin.22c8b093.js.map
