import"./jwt-decode.esm.54a1ea22.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="b3bdff78-1cd3-443f-9710-f4b76ebb6dd5",x._sentryDebugIdIdentifier="sentry-dbid-b3bdff78-1cd3-443f-9710-f4b76ebb6dd5")}catch{}})();const t=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{t as u};
//# sourceMappingURL=uuid.5b8ba8af.js.map
