import{O as d}from"./workspaceStore.fac1e9a9.js";import{d as i,J as l,a5 as c,f as t,b as n,u as o,o as u,g as r,A as f,d8 as p}from"./jwt-decode.esm.54a1ea22.js";import"./userStore.6ab1e5ac.js";import"./url.f5664225.js";import"./colorHelpers.50ced1e9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="2f1acafd-c14c-46ae-9078-a77829f9de57",e._sentryDebugIdIdentifier="sentry-dbid-2f1acafd-c14c-46ae-9078-a77829f9de57")}catch{}})();const g=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new d().loginCallback()}),(a,s)=>(u(),c("div",null,[t(o(f),null,{default:n(()=>[r("You're authenticated")]),_:1}),t(o(p),null,{default:n(()=>[r(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{g as default};
//# sourceMappingURL=OidcLoginCallback.42a7c4f9.js.map
