[data-v-e084ae6f]:root{--main-font-family: DM Sans, sans-serif}[data-v-e084ae6f]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-e084ae6f]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-e084ae6f]{background-color:#fff;padding:10px}.watermark[data-v-e084ae6f]{border-radius:8px 8px 0 0;background-color:#ffffffe6;padding:4px 12px;color:#5a677a;cursor:pointer;text-decoration:none;font-size:11px;display:flex;align-items:center;position:fixed;bottom:0;right:20px}.watermark .logo[data-v-e084ae6f]{margin-left:10px;margin-right:8px}.watermark b[data-v-e084ae6f]{font-weight:500;color:#5a677a}*[data-v-e084ae6f]{font-family:var(--main-font-family)}
