import"./jwt-decode.esm.54a1ea22.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="898a6ea9-96e5-45b2-8bb2-db9cdd4fc0e5",e._sentryDebugIdIdentifier="sentry-dbid-898a6ea9-96e5-45b2-8bb2-db9cdd4fc0e5")}catch{}})();const d=1e3,r=e=>{let n=null;return{startPolling:()=>{const t=async()=>{var o;try{!document.hidden&&!e.keepPollingOnOutOfFocus&&await e.task()}finally{n=setTimeout(t,(o=e.interval)!=null?o:d)}};t()},endPolling:()=>{n&&clearTimeout(n)}}};export{r as u};
//# sourceMappingURL=polling.b5a32c22.js.map
