import{O as s}from"./workspaceStore.fac1e9a9.js";import{d as l,J as i,a5 as u,f as a,b as o,u as n,o as f,g as d,A as c,d8 as b}from"./jwt-decode.esm.54a1ea22.js";import"./userStore.6ab1e5ac.js";import"./url.f5664225.js";import"./colorHelpers.50ced1e9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3e9915eb-192f-4ddb-af87-a3ada76833be",e._sentryDebugIdIdentifier="sentry-dbid-3e9915eb-192f-4ddb-af87-a3ada76833be")}catch{}})();const g=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new s().logoutCallback()}),(t,r)=>(f(),u("div",null,[a(n(c),null,{default:o(()=>[d("You're authenticated")]),_:1}),a(n(b),null,{default:o(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{g as default};
//# sourceMappingURL=OidcLogoutCallback.35931a68.js.map
