import{i as b}from"./metadata.0098e20c.js";import{W as h}from"./Watermark.9c9358e3.js";import{F as k}from"./PhArrowSquareOut.vue.2ddfc219.js";import{d as v,e5 as w,c as x,r as C,u as e,a5 as u,f as p,b as r,h as D,o as t,a as n,g as m,T as y,aR as I,ec as z,dc as _,ef as T,ed as F,ea as B,_ as H}from"./jwt-decode.esm.54a1ea22.js";import{u as L}from"./workspaceStore.fac1e9a9.js";import"./index.581e2edd.js";import{L as N}from"./LoadingOutlined.66639b08.js";import{C as S}from"./Card.fc77085c.js";import"./PhUserList.vue.e0b8c21b.js";import"./PhWebhooksLogo.vue.d164db1e.js";import"./constants.d569f33d.js";import"./userStore.6ab1e5ac.js";import"./url.f5664225.js";import"./colorHelpers.50ced1e9.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="7fadb32b-1704-4af5-b7a6-f3439a66b9b5",o._sentryDebugIdIdentifier="sentry-dbid-7fadb32b-1704-4af5-b7a6-f3439a66b9b5")}catch{}})();const V={key:0,class:"home-container"},W=v({__name:"Home",setup(o){const i=w(),l=L(),f=x(()=>{var s;return((s=l.state.workspace)==null?void 0:s.sidebar.filter(d=>d.id!=="home"))||[]}),c=C(null),g=async(s,d)=>{c.value=d,await i.push({path:`/${s}`}),c.value=null};return(s,d)=>e(l).state.workspace?(t(),u("div",V,[p(e(_),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[f.value.length===0?(t(),n(e(y),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[m(" There are no forms available for you. ")]),_:1})):(t(!0),u(I,{key:1},z(f.value,a=>(t(),n(e(S),{key:a.id,class:B(["form-card",{loading:c.value===a.id}]),"body-style":{cursor:"pointer"},onClick:E=>g(a.path,a.id)},{default:r(()=>[p(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(t(),n(T(e(b)(a.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),p(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[m(F(a.name),1)]),_:2},1024),c.value!==a.id?(t(),n(e(k),{key:0,size:"20"})):(t(),n(e(N),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),p(h,{class:"watermark","page-id":"home",locale:e(l).state.workspace.language},null,8,["locale"])])):D("",!0)}});const Y=H(W,[["__scopeId","data-v-060376d1"]]);export{Y as default};
//# sourceMappingURL=Home.7c495aa9.js.map
