import{d as k,r as B,J as A,o as n,a as u,b as p,f as I,g as P,ed as S,ea as C,eG as D,u as y,bR as N,eX as E,_ as h,eb as V,h as g,e as b,a5 as c,ec as v,ef as q,aR as w,E as x,F}from"./jwt-decode.esm.54a1ea22.js";import{S as L}from"./Steps.dd51a108.js";import{W as $}from"./PlayerConfigProvider.28e29025.js";import"./index.d31da2c3.js";import"./colorHelpers.50ced1e9.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="fb0825fe-cfb7-4862-84c6-5d08e41f600a",o._sentryDebugIdIdentifier="sentry-dbid-fb0825fe-cfb7-4862-84c6-5d08e41f600a")}catch{}})();const K=k({__name:"ActionButton",props:{action:{},displayName:{},disabled:{type:Boolean},loading:{type:Boolean}},emits:["click"],setup(o,{emit:t}){const d=o,l=B(null);return A(()=>{l.value&&d.action.setElement(l.value)}),(r,i)=>(n(),u(y(E),null,{default:p(()=>[I(y(N),{ref_key:"element",ref:l,class:C(["next-button",r.disabled?"disabled":""]),loading:r.loading,disabled:r.disabled,onClick:i[0]||(i[0]=f=>t("click")),onKeydown:i[1]||(i[1]=D(f=>t("click"),["enter"]))},{default:p(()=>[P(S(r.displayName),1)]),_:1},8,["loading","disabled","class"])]),_:1}))}});const R=h(K,[["__scopeId","data-v-aea27bb7"]]),J={class:"form"},M={class:"form-wrapper"},O={key:0,class:"buttons"},z=k({__name:"WidgetPreview",setup(o){const t=V(),d=B([]);function l(e){return x[e]||F[e]||null}function r(e){try{const s=JSON.parse(e);if(s.component=l(s.type),!s.component)throw new Error(`Widget ${s.type} not found`);return s.component?s:null}catch{return null}}function i(){const e=t.query.widget;return Array.isArray(e)?e.map(r).filter(Boolean):[r(e)]}function f(){return t.query.steps==="true"}function _(){const e=t.query.button;return e?Array.isArray(e)?e:[e]:[]}const m=e=>({name:e,isDefault:!1,isFocused:!1,focusOnButton:()=>{},addKeydownListener:()=>{},setElement:()=>{}});return(e,s)=>(n(),u($,{"main-color":"#d14056",class:"preview",background:"#fbfbfb","font-family":"Inter",locale:"en"},{default:p(()=>[f()?(n(),u(L,{key:0,class:"steps","steps-info":{current:1,total:3},"is-preview":""})):g("",!0),b("div",J,[b("div",M,[(n(!0),c(w,null,v(i(),(a,W)=>(n(),c("div",{key:W,class:"widget"},[(n(),u(q(a.component),{"user-props":a.userProps,value:a.userProps.value,errors:d.value},null,8,["user-props","value","errors"]))]))),128))]),_().length?(n(),c("div",O,[(n(!0),c(w,null,v(_(),a=>(n(),u(R,{key:a,"display-name":m(a).name,action:m(a)},null,8,["display-name","action"]))),128))])):g("",!0)])]),_:1}))}});const T=h(z,[["__scopeId","data-v-d3d01da6"]]);export{T as default};
//# sourceMappingURL=WidgetPreview.7c6a231c.js.map
