.connector-card[data-v-f5866f99]{cursor:pointer;transition:all .3s;&[data-v-f5866f99]:hover{box-shadow:0 0 15px #0000001a}&.unavailable[data-v-f5866f99]{opacity:.7;&[data-v-f5866f99]:hover{box-shadow:none}}}.connectors-grid[data-v-b74745a5]{display:grid;grid-template-columns:repeat(auto-fill,minmax(300px,1fr));gap:20px}
