import{P as f}from"./PlayerNavbar.aaad1dfd.js";import{d as g,e5 as h,eb as c,r as y,c as b,i as k,a5 as v,u as a,a as w,h as L,e as C,f as I,o as i,_ as N}from"./jwt-decode.esm.54a1ea22.js";import{u as V}from"./workspaceStore.fac1e9a9.js";import"./userStore.6ab1e5ac.js";import"./metadata.0098e20c.js";import"./PhUserList.vue.e0b8c21b.js";import"./PhWebhooksLogo.vue.d164db1e.js";import"./LoadingOutlined.66639b08.js";import"./PhSignOut.vue.d1d6498f.js";import"./index.c8a56795.js";import"./url.f5664225.js";import"./colorHelpers.50ced1e9.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="7b7f91e5-1a17-4696-8b2c-d67c8207fc74",o._sentryDebugIdIdentifier="sentry-dbid-7b7f91e5-1a17-4696-8b2c-d67c8207fc74")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),u=c().path,n=y(null),d=async({path:r,id:s})=>{n.value=s,await e.push({path:`/${r}`}),n.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=b(()=>!!c().meta.hideLogin);return(r,s)=>{const m=k("RouterView");return i(),v("div",x,[a(t).state.workspace?(i(),w(f,{key:0,"current-path":a(u),"hide-login":_.value,"runner-data":a(t).state.workspace,loading:n.value,onNavigate:d,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const G=N(D,[["__scopeId","data-v-f095bece"]]);export{G as default};
//# sourceMappingURL=Main.0313f4fc.js.map
