import{u as r}from"./userStore.6ab1e5ac.js";import{W as n}from"./PlayerConfigProvider.28e29025.js";import{u as c}from"./workspaceStore.fac1e9a9.js";import{d,w as i,i as p,u as o,a as u,b as f,h as l,o as m,f as _}from"./jwt-decode.esm.54a1ea22.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="ee7006ed-602e-439e-8952-dd701245cec5",t._sentryDebugIdIdentifier="sentry-dbid-ee7006ed-602e-439e-8952-dd701245cec5")}catch{}})();const v=d({__name:"App",setup(t){const a=r(),e=c();return e.actions.fetch(),i(()=>a.jwt,e.actions.fetch),(w,y)=>{const s=p("RouterView");return o(e).state.workspace?(m(),u(n,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:f(()=>[_(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):l("",!0)}}});export{v as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang.a64c7cee.js.map
