import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.e6563207.js";import{d as i,eb as s,a,u as m,o as d}from"./jwt-decode.esm.54a1ea22.js";import"./router.4dfadf5d.js";import"./index.c7a996a6.js";import"./fetch.1b3d01a0.js";import"./record.e83a2eb2.js";import"./SaveButton.428227de.js";import"./ExclamationCircleOutlined.d0aa47da.js";import"./CrudView.cc6aeaf0.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.689d8ce7.js";import"./constants.d569f33d.js";import"./url.f5664225.js";import"./PhDotsThreeVertical.vue.5e8ae2a9.js";import"./index.966ac1b9.js";import"./asyncComputed.47aec2b5.js";import"./omniChatStore.dd7a1c46.js";import"./uuid.5b8ba8af.js";import"./PhCopySimple.vue.5d0f839d.js";import"./PhPencil.vue.feb383e2.js";import"./useCodebaseEvents.276cc8f0.js";import"./contracts.generated.aefe8d0a.js";import"./index.d53182ed.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="7bbebe5d-af7b-4416-abda-739d5fd1a747",o._sentryDebugIdIdentifier="sentry-dbid-7bbebe5d-af7b-4416-abda-739d5fd1a747")}catch{}})();const A=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(f,c)=>(d(),a(n,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.5519b4ce.js.map
