import{k as r}from"./router.4dfadf5d.js";import"./jwt-decode.esm.54a1ea22.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="022ae645-203a-4232-a4b2-9b15f170328e",n._sentryDebugIdIdentifier="sentry-dbid-022ae645-203a-4232-a4b2-9b15f170328e")}catch{}})();class o{async list(e){return r.get(`organizations/${e}/folders`)}async create(e){return r.post(`organizations/${e.organizationId}/folders`,{name:e.name,memberIds:e.memberIds})}async checkNameAvailability(e,a){return r.post(`organizations/${e}/folders/name-available`,{folderName:a})}async delete(e,a){return r.delete(`organizations/${e}/folders/${a}`)}async update(e,a){return r.patch(`organizations/${e}/folders/${a.id}/`,{name:a.name,memberIds:a.memberIds})}}export{o as F};
//# sourceMappingURL=folder.13d3acac.js.map
