import{d,c as a,o as i,a5 as u,e as c,a7 as y,a6 as o,ea as r}from"./jwt-decode.esm.54a1ea22.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="0177ac26-1264-48a3-9512-7c10da2bd07f",e._sentryDebugIdIdentifier="sentry-dbid-0177ac26-1264-48a3-9512-7c10da2bd07f")}catch{}})();const b=d({__name:"ScrollArea",props:{innerClass:{},outerClass:{},outerStyle:{},innerStyle:{}},setup(e){const t=e,n=a(()=>t.outerStyle?{position:"relative",...t.outerStyle}:{position:"relative"}),l=a(()=>{var s;return{position:"absolute",inset:0,overflow:"auto",...(s=t.innerStyle)!=null?s:{}}});return(s,f)=>(i(),u("div",{style:o(n.value),class:r(s.outerClass)},[c("div",{style:o(l.value),class:r(s.innerClass)},[y(s.$slots,"default")],6)],6))}});export{b as _};
//# sourceMappingURL=ScrollArea.vue_vue_type_script_setup_true_lang.6d724b05.js.map
