import{d as a,o as d,a5 as s,e as l,a7 as r,ea as n,_ as f}from"./jwt-decode.esm.54a1ea22.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="78adfb40-5041-4436-8bbb-db5b5fbc9a8c",t._sentryDebugIdIdentifier="sentry-dbid-78adfb40-5041-4436-8bbb-db5b5fbc9a8c")}catch{}})();const b=a({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean}},setup(t){return(e,o)=>(d(),s("div",{class:n(["content-layout",{"no-padding":e.noPadding}])},[l("div",{class:n(["centered-layout",{"full-width":e.fullWidth}])},[r(e.$slots,"default",{},void 0,!0)],2)],2))}});const i=f(b,[["__scopeId","data-v-fb4d67f9"]]);export{i as C};
//# sourceMappingURL=ContentLayout.0db8d7fb.js.map
