import{L as a}from"./Logo.65e0b37c.js";import{d as n,o as r,a as d,u as f}from"./jwt-decode.esm.54a1ea22.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="bb4148b5-0ccc-4f52-bf1c-4784a5b017f7",e._sentryDebugIdIdentifier="sentry-dbid-bb4148b5-0ccc-4f52-bf1c-4784a5b017f7")}catch{}})();const i="/assets/logo.0faadfa2.svg",l=n({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(s,t)=>{var o;return r(),d(a,{"image-url":f(i),"brand-name":"Abstra","hide-text":s.hideText,size:(o=s.size)!=null?o:"small"},null,8,["image-url","hide-text","size"])}}});export{l as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.28bc9fc9.js.map
