import{L as d}from"./jwt-decode.esm.54a1ea22.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="d1660f26-d44a-4823-87b8-6aba260804c3",e._sentryDebugIdIdentifier="sentry-dbid-d1660f26-d44a-4823-87b8-6aba260804c3")}catch{}})();function p(e){return d.string().email().safeParse(e).success}function w(e){return e.charAt(0).toUpperCase()+e.slice(1)}function h(e,r,n=!1,a=!0,s=!1,t=!0){const o=(a?e.toLocaleLowerCase():e).normalize("NFD").replace(/[\u0300-\u036f]/g,""),i=`a-zA-Z0-9${s?"/":""}${t?"-":""}`,c=new RegExp(`[^${i}]`,"g"),l=o.replace(c,"_"),f=n?l:l.replace(/_+/g,"_");return r?f:f.replace(/_$/,"")}function b(e){var t;const n=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),a=/[a-z0-9]+/g,s=n.match(a);return(t=s==null?void 0:s.join("-"))!=null?t:""}function m(e,r){if(e.length===0||r.length===0)return!1;const n=e.toLowerCase(),a=r.toLowerCase();return n.split("").reduce((t,u)=>{var i;if(t===!1)return!1;const o=(i=t[t.length-1])!=null?i:null;if(o===null){const c=a.indexOf(u);return c===-1?!1:[c]}else{const l=a.slice(o+1).indexOf(u);return l===-1?!1:[...t,o+1+l]}},[])}export{h as a,w as c,m as f,p as i,b as n};
//# sourceMappingURL=string.61e11a30.js.map
