import{s as n,t as r,v as o,x as c,P as d,C as p,y as f,z as m,B as a,D as u,E as b,F as g,G as y}from"./jwt-decode.esm.54a1ea22.js";import{a as l,b as i}from"./router.06ee2b9d.js";import{s as w}from"./workspaceStore.fac1e9a9.js";import{_ as h}from"./App.vue_vue_type_style_index_0_lang.a64c7cee.js";import"./userStore.6ab1e5ac.js";import"./url.f5664225.js";import"./colorHelpers.50ced1e9.js";import"./PlayerConfigProvider.28e29025.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="cdafe543-a49e-492e-b4e4-37b139e6b761",t._sentryDebugIdIdentifier="sentry-dbid-cdafe543-a49e-492e-b4e4-37b139e6b761")}catch{}})();class _{static init(){setInterval(()=>{fetch("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const t=await l(),s=n(),e=r({render:()=>u(h)});o.init(),c(e,i,t),_.init(),e.use(i),e.use(s),e.use(d),e.mount("#app"),e.component("VSelect",p),e.component("Markdown",f),e.component("Message",m),a(e,b),a(e,g),a(e,y)})();
//# sourceMappingURL=player.4ab4aed5.js.map
