import{d as t,o as d,a5 as o,f as s,u as _,S as r,_ as f}from"./jwt-decode.esm.54a1ea22.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="aa184d25-f494-493f-ab97-8205d3dff065",e._sentryDebugIdIdentifier="sentry-dbid-aa184d25-f494-493f-ab97-8205d3dff065")}catch{}})();const i={class:"centered"},c=t({__name:"LoadingContainer",setup(e){return(n,a)=>(d(),o("div",i,[s(_(r))]))}});const u=f(c,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.82ac3d44.js.map
