[data-v-da85ecdc]:root{--main-font-family: DM Sans, sans-serif}[data-v-da85ecdc]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-da85ecdc]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-da85ecdc]{background-color:#fff;padding:10px}.base-layout[data-v-da85ecdc]{display:flex;position:relative;overflow:hidden;height:100vh}.base-layout .base-middle[data-v-da85ecdc]{display:flex;flex-direction:column;flex-grow:1;width:100vw;height:100%;overflow:hidden}.base-layout .base-middle .content[data-v-da85ecdc]{display:flex;flex-grow:1;width:100%;height:100%;overflow:hidden}.base-layout .base-middle .left[data-v-da85ecdc]{display:flex;flex-direction:column;flex-grow:1;width:100%;height:100%;overflow:hidden}.base-layout .base-footer[data-v-da85ecdc]{width:100%}
