.cli[data-v-b7f04a41]{background-color:#555;border-radius:5px;padding:10px;color:#fff;font-family:monospace}[data-v-cdd3162a]:root{--abstra-main-color-dark: #343b46}.tree[data-v-cdd3162a] .ant-tree-node-content-wrapper{user-select:auto}.ask-to-ai[data-v-cdd3162a]{display:flex;gap:6px;align-items:center;cursor:pointer;color:#d14056}.ask-to-ai.disabled[data-v-cdd3162a]{cursor:not-allowed;opacity:.5}
