@charset "UTF-8";.related-tables[data-v-d16c88ca]{padding:0}.related-section[data-v-d16c88ca]{margin-bottom:32px}.related-section h3[data-v-d16c88ca]{font-size:16px;font-weight:600;margin-bottom:16px;color:#262626}.related-table-card[data-v-d16c88ca]{min-width:280px;max-width:320px;cursor:pointer;transition:all .3s ease}.related-table-card[data-v-d16c88ca]:not(.loading-card):hover{transform:translateY(-2px);box-shadow:0 4px 12px #00000026}.related-table-card.loading-card[data-v-d16c88ca]{cursor:default}.related-table-card[data-v-d16c88ca] .ant-card-head-title{font-weight:600;font-size:14px}.related-table-card[data-v-d16c88ca] .ant-skeleton-title{margin:0}.relation-info[data-v-d16c88ca]{display:flex;align-items:center;gap:8px;margin:0;font-size:13px;color:#595959}.relation-info span[data-v-d16c88ca]{font-family:monospace;background:#f5f5f5;padding:2px 6px;border-radius:4px}.no-relations[data-v-d16c88ca]{padding:40px 0;display:flex;justify-content:center}.icon[data-v-6ae5cef6]{cursor:pointer;display:flex}.twin-container[data-v-5f7e2cd2]{display:flex;align-items:center;gap:20px}.right-arrow[data-v-5f7e2cd2]{width:50px}.using-container[data-v-5f7e2cd2]{display:flex;gap:40px}.fullwidth-input[data-v-5f7e2cd2]{width:100%}:root{--main-font-family: DM Sans, sans-serif}:root{--abstra-main-color-dark: #343b46}.p-dropdown{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel{background-color:#fff;padding:10px}.table-data{padding:30px 0}.table-row{overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.table-row.null{color:#ccc}.table-row.expanded{white-space:normal}.button-container{display:flex;justify-content:center;align-items:center}.foreign-key-popover{min-width:280px;max-width:400px;max-height:400px;overflow-y:auto;padding:0}.popover-loading{display:flex;justify-content:center;align-items:center;padding:20px}.foreign-key-field{padding:10px 12px;border-bottom:1px solid #f0f0f0}.foreign-key-field:last-child{border-bottom:none}.field-label{font-size:11px;font-weight:600;color:#8c8c8c;text-transform:uppercase;letter-spacing:.5px;margin-bottom:4px}.field-value{font-size:13px;color:#262626;word-break:break-word;line-height:1.4}.field-value:empty:before{content:"\2014";color:#d9d9d9}.foreign-key-error{color:#ff4d4f;font-size:13px;padding:12px;text-align:center}.foreign-key-tag{cursor:pointer;margin:0}.foreign-key-tag :deep(a){color:inherit;text-decoration:none}.foreign-key-tag :deep(a):hover{color:inherit}.foreign-key-link{color:inherit;cursor:pointer}.foreign-key-link:hover{text-decoration:none}.nested-fk-tag{cursor:pointer;margin:0}.nested-fk-tag:hover{opacity:.8}
