import{A as o}from"./index.d31da2c3.js";import{d as r,c as a,a5 as p,f as d,u as c,ea as f,h as l,o as i,_ as u}from"./jwt-decode.esm.54a1ea22.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="e837cb0e-3c6d-4eb6-954d-2acf9bee7847",e._sentryDebugIdIdentifier="sentry-dbid-e837cb0e-3c6d-4eb6-954d-2acf9bee7847")}catch{}})();const _=r({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,n=a(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(t,m)=>t.stepsInfo?(i(),p("nav",{key:0,class:f(["p-steps",{"full-screen":!t.isPreview}])},[d(c(o),{current:t.stepsInfo.current-1,items:n.value,responsive:!1},null,8,["current","items"])],2)):l("",!0)}});const I=u(_,[["__scopeId","data-v-58fdd395"]]);export{I as S};
//# sourceMappingURL=Steps.dd51a108.js.map
