import{d as i,ez as c,c as r,o,a5 as t,h as d,ea as _,ed as p,_ as u}from"./jwt-decode.esm.54a1ea22.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="d7703b1b-8e30-4a2d-9127-ff48a5778ede",e._sentryDebugIdIdentifier="sentry-dbid-d7703b1b-8e30-4a2d-9127-ff48a5778ede")}catch{}})();const f={class:"logo"},g=["src","alt"],m=i({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const s=e;c(a=>({"4521d904":n.value}));const n=r(()=>s.size==="small"?"24px":s.size==="large"?"80px":"50px"),l=r(()=>`${s.brandName} Logo`);return(a,y)=>(o(),t("div",f,[a.imageUrl?(o(),t("img",{key:0,class:"logo-img",src:a.imageUrl,alt:l.value},null,8,g)):d("",!0),a.hideText?d("",!0):(o(),t("span",{key:1,class:_(a.size)},p(a.brandName),3))]))}});const h=u(m,[["__scopeId","data-v-8f34aac0"]]);export{h as L};
//# sourceMappingURL=Logo.65e0b37c.js.map
