import"./jwt-decode.esm.54a1ea22.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="28e6c4d9-74b2-492f-ac6d-10e5bb9d20f8",t._sentryDebugIdIdentifier="sentry-dbid-28e6c4d9-74b2-492f-ac6d-10e5bb9d20f8")}catch{}})();const s={HOMEPAGE:{}.VITE_HOMEPAGE_URL||"https://abstra.io",DOCS:{}.VITE_DOCS_URL||"https://abstra.io/docs",CLOUD:{}.VITE_CONSOLE_URL||"https://cloud.abstra.io",GITHUB:{}.VITE_GITHUB_URL||"https://github.com/abstra-app/abstra-lib"},b=t=>{if(!t)return s.DOCS;const e=t.startsWith("/")?t.slice(1):t;return`${s.DOCS}/${e}`};export{s as A,b};
//# sourceMappingURL=constants.d569f33d.js.map
