import{f as d,e7 as u,eY as f}from"./jwt-decode.esm.54a1ea22.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8a826157-9fb6-4e5e-9b5e-b916bca33c5b",e._sentryDebugIdIdentifier="sentry-dbid-8a826157-9fb6-4e5e-9b5e-b916bca33c5b")}catch{}})();function o(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){b(e,a,n[a])})}return e}function b(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var i=function(t,n){var r=o({},t,n.attrs);return d(u,o({},r,{icon:f}),null)};i.displayName="LoadingOutlined";i.inheritAttrs=!1;const l=i;export{l as L};
//# sourceMappingURL=LoadingOutlined.66639b08.js.map
