import{O as s}from"./OmniChat.73d9f6bb.js";import{u as i}from"./omniChatStore.dd7a1c46.js";import{d as a,eb as c,u as t,o as d,a as u,h as l}from"./jwt-decode.esm.54a1ea22.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="4f103760-3708-4422-9438-b754843f2ed2",e._sentryDebugIdIdentifier="sentry-dbid-4f103760-3708-4422-9438-b754843f2ed2")}catch{}})();const b=a({__name:"ConsoleOmniChat",setup(e){const n=c().params.projectId,o=i();return o.init("console",n),(f,p)=>t(o).controller&&t(o).repository?(d(),u(s,{key:0,"ai-chat-repository":t(o).repository,controller:t(o).controller,environment:{origin:"console",projectId:t(n)},"show-console-suggestions":!0},null,8,["ai-chat-repository","controller","environment"])):l("",!0)}});export{b as _};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang.3ca66327.js.map
