import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.5161f328.js";import{d as m,e5 as f,eb as b,a5 as g,f as y,u as n,o as w,_ as k}from"./jwt-decode.esm.54a1ea22.js";import{u as h}from"./workspaceStore.fac1e9a9.js";import"./CircularLoading.998b223a.js";import"./Logo.65e0b37c.js";import"./string.61e11a30.js";import"./index.d53182ed.js";import"./userStore.6ab1e5ac.js";import"./url.f5664225.js";import"./colorHelpers.50ced1e9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="25fb1986-d76d-4947-a601-4072c70dc93b",e._sentryDebugIdIdentifier="sentry-dbid-25fb1986-d76d-4947-a601-4072c70dc93b")}catch{}})();const v={class:"runner"},I=m({__name:"Login",setup(e){const o=f(),t=b(),r=h(),_=async()=>{const{redirect:a,...s}=t.query;if(a){await o.push({path:a,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>{var c,d,p,u,i;return w(),g("div",v,[y(l,{"logo-url":(d=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(p=n(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const H=k(I,[["__scopeId","data-v-12c690e1"]]);export{H as default};
//# sourceMappingURL=Login.4a05f5c5.js.map
