[data-v-2be8fa34]:root{--main-font-family: DM Sans, sans-serif}[data-v-2be8fa34]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-2be8fa34]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-2be8fa34]{background-color:#fff;padding:10px}.files-navigator[data-v-2be8fa34]{display:flex;flex-direction:column;gap:20px}.files-navigator .scroll-area[data-v-2be8fa34]{border:1px solid lightgray;border-radius:6px}.files-navigator .list-header[data-v-2be8fa34]{position:sticky;top:0;z-index:10;background:white;padding:12px;border-radius:6px 6px 0 0;border-bottom:1px solid #f0f0f0}.files-navigator .file-size[data-v-2be8fa34]{color:#8692a5;margin-left:5px}.files-navigator .header-container[data-v-2be8fa34]{padding:4px 8px;border-radius:4px;background-color:#f8f9fa;border:1px solid #e9ecef;flex-shrink:0;min-width:0}.files-navigator .header-container[data-v-2be8fa34] .ant-breadcrumb{overflow:hidden}.files-navigator .header-container[data-v-2be8fa34] .ant-breadcrumb ol{display:flex;align-items:center;flex-wrap:nowrap;overflow:hidden}.files-navigator .header-container[data-v-2be8fa34] .ant-breadcrumb li{white-space:nowrap;overflow:hidden;text-overflow:ellipsis;min-width:0}.files-navigator .header-container[data-v-2be8fa34] .ant-breadcrumb li:not(:last-child){flex-shrink:1}.files-navigator .header-container[data-v-2be8fa34] .ant-breadcrumb li:last-child{flex-shrink:0}.files-navigator .selection-info[data-v-2be8fa34]{color:#ffee56;font-weight:500;font-size:14px}.files-navigator .char-match[data-v-2be8fa34]{background-color:#ffee56}.files-navigator .files-list[data-v-2be8fa34] .ant-list-item{padding:8px 12px!important;border-bottom:1px solid #f0f0f0}.files-navigator .files-list[data-v-2be8fa34] .ant-list-item:hover{background-color:#fafafa}.files-navigator .files-list[data-v-2be8fa34] .ant-list-item-meta{margin-bottom:0}.files-navigator .files-list[data-v-2be8fa34] .ant-list-item-meta-avatar{margin-right:12px}.files-navigator .files-list[data-v-2be8fa34] .ant-list-item-meta-content{display:flex;flex-direction:column;justify-content:center}.files-navigator .files-list[data-v-2be8fa34] .ant-list-item-meta-title{margin-bottom:2px;font-size:14px;line-height:1.4}.files-navigator .files-list[data-v-2be8fa34] .ant-list-item-meta-description{font-size:12px;color:#8c8c8c;line-height:1.2}[data-v-d42eb84d]:root{--main-font-family: DM Sans, sans-serif}[data-v-d42eb84d]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-d42eb84d]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-d42eb84d]{background-color:#fff;padding:10px}.files-container[data-v-d42eb84d]{width:100%;height:calc(100vh - 140px);margin-bottom:30px;box-sizing:border-box;display:flex;flex-direction:column;gap:16px}.files-card[data-v-d42eb84d]{flex-grow:1;display:flex;flex-direction:column}.files-card[data-v-d42eb84d] .ant-card-body{flex-grow:1;display:flex;flex-direction:column;padding:16px}.files-navigator[data-v-d42eb84d]{flex-grow:1}
