[data-v-12c690e1]:root{--main-font-family: DM Sans, sans-serif}[data-v-12c690e1]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-12c690e1]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-12c690e1]{background-color:#fff;padding:10px}.runner[data-v-12c690e1]{width:100%;height:100%;position:relative;display:flex;flex-direction:column;align-items:center;justify-content:center;background-color:#e9eaeb}
