import{k as a}from"./router.4dfadf5d.js";import"./jwt-decode.esm.54a1ea22.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="60562fac-9c0a-4bdd-9c98-ce39b42ada52",r._sentryDebugIdIdentifier="sentry-dbid-60562fac-9c0a-4bdd-9c98-ce39b42ada52")}catch{}})();class s{async create(e){return a.post(`organizations/${e.organizationId}/members`,{email:e.email,folderIds:e.folderIds})}async delete(e){return a.delete(`organizations/${e.organizationId}/members/${e.authorId}`)}async list(e){return a.get(`organizations/${e}/members`)}async get(e,n){return a.get(`organizations/${e}/members/${n}`)}async update(e,n,t){return a.patch(`organizations/${e}/members/${n}`,t)}}export{s as M};
//# sourceMappingURL=member.2260c37e.js.map
